@@ -758,6 +758,10 @@ class GitObjectStorageContext(
             change = delta.status_char()
             fileName = delta.new_file.path
 
+            if "/" not in fileName:  # Ignore changes to files in root directory
+                logger.info(f"Ignoring file {fileName} from changelog")
+                continue
+
             itemType, itemKey, *pathTail = fileName.split("/")
             # We only include item modifications for now
             # TODO: Expand this to include other changes
