@@ -17,6 +17,9 @@ from attune_project_api.items.file_archive_tuples.file_tuple_constants import (
 from attune_project_api.items.file_archive_tuples.file_tuple_constants import (
     ARCHIVE_FORMAT_KEY_TAR_XZ,
 )
+from attune_project_api.items.file_archive_tuples.file_tuple_constants import (
+    ARCHIVE_FORMAT_KEY_UNKNOWN,
+)
 from attune_project_api.items.file_archive_tuples.file_tuple_constants import (
     ARCHIVE_FORMAT_KEY_ZIP,
 )
@@ -33,7 +36,11 @@ def __registerArchiveLister(key: str):
 
 
 def canListFiles(archiveFormatKey: str) -> bool:
-    return archiveFormatKey in __ARCHIVE_LISTER_BY_FORMAT_KEY
+    # Unknown zip formats are not browsable
+    return (
+        archiveFormatKey in __ARCHIVE_LISTER_BY_FORMAT_KEY
+        and archiveFormatKey != ARCHIVE_FORMAT_KEY_UNKNOWN
+    )
 
 
 def listArchiveFiles(path: Path) -> list[ArchiveFileInfo]:
@@ -82,3 +89,8 @@ def _listTarFile(path: Path) -> list[ArchiveFileInfo]:
             for m in members
             if m.type != DIRTYPE
         ]
+
+
+@__registerArchiveLister(ARCHIVE_FORMAT_KEY_UNKNOWN)
+def _listUnknownFiles(path: Path) -> list[ArchiveFileInfo]:
+    return []
