@@ -15,3 +15,7 @@ def makeStorageKey(value: str) -> str:
     while "_" in value:
         value = value.replace("_", "")
     return value
+
+
+def makeStorageKeyFromScriptRef(scriptRef: str) -> str:
+    return makeStorageKey(scriptRef.split(".")[0])
